@@ -1,9 +1,10 @@
 import holidays
 from datetime import date
 from dateutil.relativedelta import relativedelta, MO, FR
-from dateutil.easter import easter
+# from dateutil.easter import easter
 
-class TradingHolidays(holidays.UnitedStates):
+
+class TradingHolidays(holidays.countries.UnitedStates):
 	def _populate(self, year):
 		# Populate the holiday list with the default US holidays
 		holidays.UnitedStates._populate(self, year)
@@ -11,6 +12,8 @@ class TradingHolidays(holidays.UnitedStates):
 		self.pop(date(year, 10, 1) + relativedelta(weekday=MO(+2)), None)
 		# Remove Veterans Day
 		self.pop(date(year, 11, 11), None)
+		if year==2023:
+			self.pop(date(year, 11, 10), None)
 
 		# # Add Good Friday # NOTE: removed this since Good Friday is not a bond market holiday - [04/01/2021]
 		# self[easter(year) + relativedelta(weekday=FR(-1))] = "Good Friday"
